:orphan:



.. _sphx_glr__gallery:

.. This directory contains scripts to use as tutorials to understand the package
   Use plot_*.py for script that intend to display some feature and will be
   rendered in the package gallery

Gallery
=======

Example plots of available features



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Plot heat conductance between canopy (or soil) and atmosphere as a function of wind speed.">

.. only:: html

 .. figure:: /_gallery/images/thumb/sphx_glr_plot_heat_conductance_thumb.png
     :alt: Heat conductance canopy atmosphere

     :ref:`sphx_glr__gallery_plot_heat_conductance.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /_gallery/plot_heat_conductance
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
